@@ -1,11 +1,12 @@
 var group__pw__thread =
 [
-    [ "thread.h", "src_2pipewire_2thread_8h.html", null ],
+    [ "src/pipewire/thread.h", "src_2pipewire_2thread_8h.html", null ],
     [ "pw_thread_utils_create", "group__pw__thread.html#gaf6d1af37e20c59b091c420cd5d61703d", null ],
     [ "pw_thread_utils_join", "group__pw__thread.html#ga44e75b0ce3d7de0e5363ae8e477d6c56", null ],
     [ "pw_thread_utils_get_rt_range", "group__pw__thread.html#gac04215799f912843498d14d70787469b", null ],
     [ "pw_thread_utils_acquire_rt", "group__pw__thread.html#gae4ccb8e430642c0ba5c0f274b00c2e41", null ],
     [ "pw_thread_utils_drop_rt", "group__pw__thread.html#ga3d65fa7f9f3362071848bbe40c974aaf", null ],
     [ "pw_thread_utils_set", "group__pw__thread.html#ga57b388a269e2682fd9bc46bb9f46efec", null ],
-    [ "pw_thread_utils_get", "group__pw__thread.html#ga4f44f914821635ec123cf0a0ae2d0b5d", null ]
+    [ "pw_thread_utils_get", "group__pw__thread.html#ga4f44f914821635ec123cf0a0ae2d0b5d", null ],
+    [ "pw_thread_fill_attr", "group__pw__thread.html#ga09ac2a140526a285e1af5e7ddd2fe672", null ]
 ];
\ No newline at end of file
